Legal Aid of West Virginia's Kinship Connector.

This tool is designed to assist the general public with educating themselves on the different types of kinship arrangements available to them.  Once the user chooses a document to create, the interview will guide the user in entering the information needed to complete either a 1) Temporary Care Agreement, 2) Infant Guardianship, or 3) Adoption packet.  Once completed, these packets will provide instructions to the users on the next steps in their kinship process, including when and where to sign and how to print and submit to the court (if necessary).

This project was developed as part of a LSC TIG and made available for reproduction and modification pursuant to grant requirements.